@@ -194,7 +194,7 @@ class TIBasicParser(object):
 			self.indentIncrease = True
 		# Repeat loop (tests at bottom)
 		elif line.startswith("Repeat "):
-			statement = ["firstPass = True", "while firstPass == True or " + fixEquals(line[7:]) + ":", "\tfirstPass = False"]
+			statement = ["firstPass = True", "while firstPass == True or not (" + fixEquals(line[7:]) + "):", "\tfirstPass = False"]
 			self.indentIncrease = True
 		# Pause
 		elif line.startswith("Pause"):
